@@ -1,41 +1,41 @@
 
 module Config
 
-  VERSION == "1.6.3" or
-    raise "ruby lib version (1.6.3) doesn't match executable version (#{VERSION})"
+  RUBY_VERSION == "1.6.4" or
+    raise "ruby lib version (1.6.4) doesn't match executable version (#{RUBY_VERSION})"
 
 # This file was created by configrb when ruby was built. Any changes
 # made to this file will be lost the next time ruby is built.
   DESTDIR = '' if not defined? DESTDIR
   CONFIG = {}
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-cygwin\Z', '')
-  CONFIG["srcdir"] = "/home/pub/ruby/16/dist/ruby-1.6.3"
+  CONFIG["srcdir"] = "/home/pub/ruby/16/dist/ruby-1.6.4"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["CFLAGS"] = "-Os -mwin32 "
+  CONFIG["CFLAGS"] = "-Os "
   CONFIG["CPPFLAGS"] = ""
   CONFIG["CXXFLAGS"] = ""
   CONFIG["FFLAGS"] = ""
   CONFIG["LDFLAGS"] = ""
   CONFIG["LIBS"] = ""
-  CONFIG["exec_prefix"] = "#{CONFIG[\"prefix\"]}"
-  CONFIG["bindir"] = "#{CONFIG[\"exec_prefix\"]}/bin"
-  CONFIG["sbindir"] = "#{CONFIG[\"exec_prefix\"]}/sbin"
-  CONFIG["libexecdir"] = "#{CONFIG[\"exec_prefix\"]}/libexec"
-  CONFIG["datadir"] = "#{CONFIG[\"prefix\"]}/share"
-  CONFIG["sysconfdir"] = "#{CONFIG[\"prefix\"]}/etc"
-  CONFIG["sharedstatedir"] = "#{CONFIG[\"prefix\"]}/com"
-  CONFIG["localstatedir"] = "#{CONFIG[\"prefix\"]}/var"
-  CONFIG["libdir"] = "#{CONFIG[\"exec_prefix\"]}/lib"
+  CONFIG["exec_prefix"] = "$(prefix)"
+  CONFIG["bindir"] = "$(exec_prefix)/bin"
+  CONFIG["sbindir"] = "$(exec_prefix)/sbin"
+  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
+  CONFIG["datadir"] = "$(prefix)/share"
+  CONFIG["sysconfdir"] = "$(prefix)/etc"
+  CONFIG["sharedstatedir"] = "$(prefix)/com"
+  CONFIG["localstatedir"] = "$(prefix)/var"
+  CONFIG["libdir"] = "$(exec_prefix)/lib"
   CONFIG["includedir"] = "/usr/local/cygwin-local/include"
   CONFIG["oldincludedir"] = "/usr/include"
-  CONFIG["infodir"] = "#{CONFIG[\"prefix\"]}/info"
-  CONFIG["mandir"] = "#{CONFIG[\"prefix\"]}/man"
+  CONFIG["infodir"] = "$(prefix)/info"
+  CONFIG["mandir"] = "$(prefix)/man"
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "6"
-  CONFIG["TEENY"] = "3"
+  CONFIG["TEENY"] = "4"
   CONFIG["host"] = "i686-pc-cygwin"
   CONFIG["host_alias"] = "i686-pc-cygwin"
   CONFIG["host_cpu"] = "i686"
@@ -61,7 +61,6 @@ module Config
   CONFIG["AS"] = "as"
   CONFIG["DLLTOOL"] = "dlltool"
   CONFIG["WINDRES"] = "windres"
-  CONFIG["MWIN32"] = "-mwin32"
   CONFIG["LN_S"] = "ln -s"
   CONFIG["SET_MAKE"] = ""
   CONFIG["OBJEXT"] = "o"
@@ -77,7 +76,7 @@ module Config
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/cygwin -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.4/cobj -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["LIBRUBY_LDSHARED"] = "dllwrap --target=cygwin --as=as --dlltool-name=dlltool --driver-name=gcc --export-all -s"
   CONFIG["LIBRUBY_DLDFLAGS"] = "--dllname=$@ --output-lib=$(LIBRUBY) --add-stdcall-alias --def=$(RUBYDEF)"
@@ -91,17 +90,23 @@ module Config
   CONFIG["SOLIBS"] = "$(LIBS)"
   CONFIG["DLDLIBS"] = ""
   CONFIG["ENABLE_SHARED"] = "yes"
+  CONFIG["MAINLIBS"] = ""
   CONFIG["arch"] = "i386-cygwin"
-  CONFIG["sitedir"] = "#{CONFIG[\"prefix\"]}/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "--target=i386-cygwin --host=i686-pc-cygwin --build=i586-pc-linux-gnu --program-prefix= --includedir=/usr/local/cygwin-local/include --srcdir=../ruby-1.6.3 --cache=../config.cache-cygwin --with-tcl-dir=/usr/local/mingw --with-tk-dir=/usr/local/mingw --enable-tcltk_stubs --with-tcllib=tclstub83 --with-tklib=tkstub83 --with-opt-dir=/usr/local/cygwin-local --enable-shared"
-  CONFIG["compile_dir"] = "/home/pub/ruby/16/dist/cygwin"
+  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
+  CONFIG["configure_args"] = "--target=i386-cygwin --host=i686-pc-cygwin --build=i586-pc-linux-gnu --program-prefix= --includedir=/usr/local/cygwin-local/include --with-tcl-dir=/usr/local/mingw --with-tk-dir=/usr/local/mingw --enable-tcltk_stubs --with-tcllib=tclstub83 --with-tklib=tkstub83 --with-curses-dir=/usr/local/cygwin-local/ncurses --with-opt-dir=/usr/local/cygwin-local --enable-shared"
+  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
+  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
+  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
+  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
+  CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
+  CONFIG["compile_dir"] = "/home/pub/ruby/16/dist/ruby-1.6.4/cobj"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val)
     val.gsub!(/\$\(([^()]+)\)/) do |var|
       key = $1
       if CONFIG.key? key
-        "#{Config::expand(CONFIG[\"#{key}\"])}"
+        Config::expand(CONFIG[key])
       else
 	var
       end
